@@ -2,29 +2,28 @@
 #ifndef _GLIBMM_TIMEVAL_H
 #define _GLIBMM_TIMEVAL_H
 
-/* $Id: timeval.h 317 2006-08-18 14:59:17Z  $ */
+/* $Id: timeval.h 779 2009-01-19 17:58:50Z murrayc $ */
 
 /* timeval.h
  *
  * Copyright (C) 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glib/gtypes.h>
-#include <glib/gtimer.h>
+#include <glib.h>
 
 namespace Glib
 {
